#!/bin/bash
#

# build_larcv.sh <product_dir> <quals> <debug|prof> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> <quals> <debug|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=larcv
origpkgver_py2=v06_70_00g   # Source code git tag (python 2).
origpkgver_py3=v06_71_00    # Source code git tag (python 3).
pkgver=v06_71_00a           # New ups version.
ssibuildshims_version=v1_04_14

if [[ "${basequal}" =~ py2 ]]; then
  origpkgver=$origpkgver_py2
elif [[ "${basequal}" =~ py3 ]]; then
  origpkgver=$origpkgver_py3
else
  origpkgver=$origpkgver_py3   # Default is py3
fi

pkgtarname=larcv-${origpkgver}    # Source code tarball name

get_this_dir

get_ssibuildshims

source define_basics --

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/build/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# setup fake package and dependencies (root).
setup ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || die "ERROR: fake setup failed"

set -x

cd ${blddir}
tar xf ${tardir}/${pkgtarname}.tar
# patch required for c7, but OK for all
patch -b -p0 < ${patchdir}/${pkgtarname}.patch

cd ${blddir}/${pkgtarname}

source configure.sh

# Override the config's choice of compiler according to our qualifiers.

if [[ "${basequal}" =~ ^c ]]; then
  export LARCV_CXX=clang++
else
  export LARCV_CXX=g++
fi

make -j$ncore

set +x

# Ignore table file stored in source code repo.
# Use table file from ssi-biuld repo instead.

rm -rf ups

# Copy everything else to $pkgdir.

cp -r * ${pkgdir}

if [ ! -d ${pkgdir}/build/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/build/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}

# this must be last 
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/build/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
